@@ -2,14 +2,14 @@ import pandas as pd
 import numpy as np 
 
 
-def supertrend(df,atr_periodsuper,factorsuper):
+def supertrend(df,atr_longitud,factor):
     price_diffs = [df['high'].astype(float) - df['low'].astype(float),df['high'].astype(float) - df['close'].astype(float).shift(),df['close'].astype(float).shift() - df['low'].astype(float)]
     true_range = pd.concat(price_diffs, axis=1)
     true_range = true_range.abs().max(axis=1)
-    atr = true_range.ewm(alpha=1/atr_periodsuper,min_periods=atr_periodsuper).mean() 
+    atr = true_range.ewm(alpha=1/atr_longitud,min_periods=atr_longitud).mean() 
     hl2 = (df['high'].astype(float) + df['low'].astype(float)) / 2
-    final_upperband = upperband = hl2 + (factorsuper * atr)
-    final_lowerband = lowerband = hl2 - (factorsuper * atr)
+    final_upperband = upperband = hl2 + (factor * atr)
+    final_lowerband = lowerband = hl2 - (factor * atr)
     supertrend = [True] * len(df)
     for i in range(1, len(df.index)):
         curr, prev = i, i-1
@@ -52,23 +52,23 @@ def supertrend(df,atr_periodsuper,factorsuper):
         seniales="Venta"
 
     return seniales
-def bandas_bollinger(datos, periodo, desviaciones):
-    datos['media'] = datos['close'].rolling(window=periodo).mean()
-    media_movil = datos['close'].rolling(window=periodo).mean()
-    desviacion_estandar = datos['close'].rolling(window=periodo).std(ddof=0)
-    banda_superior = media_movil.astype(float) + desviaciones * desviacion_estandar.astype(float)
-    banda_inferior = media_movil.astype(float) - desviaciones * desviacion_estandar.astype(float)
-    ultima_media = datos['media'].iloc[-1]
+def bandas_bollinger(df, longitud, desviacion):
+    df['media'] = df['close'].rolling(window=longitud).mean()
+    media_movil = df['close'].rolling(window=longitud).mean()
+    desviacion_estandar = df['close'].rolling(window=longitud).std(ddof=0)
+    banda_superior = media_movil.astype(float) + desviacion * desviacion_estandar.astype(float)
+    banda_inferior = media_movil.astype(float) - desviacion * desviacion_estandar.astype(float)
+    ultima_media = df['media'].iloc[-1]
     ultima_banda_superior = banda_superior.iloc[-1]
     ultima_banda_inferior = banda_inferior.iloc[-1]
     return ultima_media, ultima_banda_superior, ultima_banda_inferior
-def estocastico(df,k_period,d_period):
-    high_roll = df["high"].rolling(k_period).max()
-    low_roll = df["low"].rolling(k_period).min()
+def estocastico(df,k_periodo,d_periodo):
+    high_roll = df["high"].rolling(k_periodo).max()
+    low_roll = df["low"].rolling(k_periodo).min()
     num = df["close"].astype(float) - low_roll.astype(float)
     denom = high_roll.astype(float) - low_roll.astype(float)
     df["%K"] = (num / denom) * 100
-    df["%D"] = df["%K"].rolling(d_period).mean()
+    df["%D"] = df["%K"].rolling(d_periodo).mean()
     estocasticok=df["%K"].iloc[-1]
     estocasticod=df["%D"].iloc[-1]
     return estocasticok,estocasticod
